﻿using System.Collections.Generic;
using System.Linq;

namespace TestProject
{
    /// <summary>
    /// MIME 타입 헬퍼
    /// </summary>
    public static class MIMETypeHelper
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Field
        ////////////////////////////////////////////////////////////////////////////////////////// Static
        //////////////////////////////////////////////////////////////////////////////// Private

        #region Field

        /// <summary>
        /// 알려진 타입 리스트
        /// </summary>
        private static List<string> _knownTypeList;

        /// <summary>
        /// MIME 타입 딕셔너리
        /// </summary>
        private static Dictionary<string, string> _mimeTypeDictionary;

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Property
        ////////////////////////////////////////////////////////////////////////////////////////// Static
        //////////////////////////////////////////////////////////////////////////////// Public

        #region 알려진 타입 리스트 - KnownTypeList

        /// <summary>
        /// 알려진 타입 리스트
        /// </summary>
        public static List<string> KnownTypeList
        {
            get
            {
                return _knownTypeList;
            }
        }

        #endregion
        #region MIME 타입 딕셔너리 - MIMETypeDictionary

        /// <summary>
        /// MIME 타입 딕셔너리
        /// </summary>
        public static Dictionary<string, string> MIMETypeDictionary
        {
            get
            {
                return _mimeTypeDictionary;
            }
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Constructor
        ////////////////////////////////////////////////////////////////////////////////////////// Static

        #region 생성자 - MIMETypeHelper()

        /// <summary>
        /// 생성자
        /// </summary>
        static MIMETypeHelper()
        {
            Initialize();
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Static
        //////////////////////////////////////////////////////////////////////////////// Public

        #region MIME 타입 구하기 - GetMIMEType(fileExtension)

        /// <summary>
        /// MIME 타입 구하기
        /// </summary>
        /// <param name="fileExtension">파일 확장자</param>
        /// <returns>MIME 타입</returns>
        public static string GetMIMEType(string fileExtension)
        {
            if(MIMETypeDictionary.ContainsKey(fileExtension))
            {
                return MIMETypeDictionary[fileExtension];
            }
            else
            {
                return "application/octet-stream";
            }
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////// Private

        #region 초기화하기 - Initialize()

        /// <summary>
        /// 초기화하기
        /// </summary>
        private static void Initialize()
        {
            _knownTypeList = new string[]
            {
                "text/plain",
                "text/html",
                "text/xml",
                "text/richtext",
                "text/scriptlet",
                "audio/x-aiff",
                "audio/basic",
                "audio/mid",
                "audio/wav",
                "image/gif",
                "image/jpeg",
                "image/pjpeg",
                "image/png",
                "image/x-png",
                "image/tiff",
                "image/bmp",
                "image/x-xbitmap",
                "image/x-jg",
                "image/x-emf",
                "image/x-wmf",
                "video/avi",
                "video/mpeg",
                "application/octet-stream",
                "application/postscript",
                "application/base64",
                "application/macbinhex40",
                "application/pdf",
                "application/xml",
                "application/atom+xml",
                "application/rss+xml",
                "application/x-compressed",
                "application/x-zip-compressed",
                "application/x-gzip-compressed",
                "application/java",
                "application/x-msdownload"
            }.ToList();

            _mimeTypeDictionary = new Dictionary<string, string>();

            _mimeTypeDictionary.Add(".3dm"      , "x-world/x-3dmf"                                       );
            _mimeTypeDictionary.Add(".3dmf"     , "x-world/x-3dmf"                                       );
            _mimeTypeDictionary.Add(".a"        , "application/octet-stream"                             );
            _mimeTypeDictionary.Add(".aab"      , "application/x-authorware-bin"                         );
            _mimeTypeDictionary.Add(".aam"      , "application/x-authorware-map"                         );
            _mimeTypeDictionary.Add(".aas"      , "application/x-authorware-seg"                         );
            _mimeTypeDictionary.Add(".abc"      , "text/vnd.abc"                                         );
            _mimeTypeDictionary.Add(".acgi"     , "text/html"                                            );
            _mimeTypeDictionary.Add(".afl"      , "video/animaflex"                                      );
            _mimeTypeDictionary.Add(".ai"       , "application/postscript"                               );
            _mimeTypeDictionary.Add(".aif"      , "audio/aiff"                                           );
            _mimeTypeDictionary.Add(".aifc"     , "audio/aiff"                                           );
            _mimeTypeDictionary.Add(".aiff"     , "audio/aiff"                                           );
            _mimeTypeDictionary.Add(".aim"      , "application/x-aim"                                    );
            _mimeTypeDictionary.Add(".aip"      , "text/x-audiosoft-intra"                               );
            _mimeTypeDictionary.Add(".ani"      , "application/x-navi-animation"                         );
            _mimeTypeDictionary.Add(".aos"      , "application/x-nokia-9000-communicator-add-on-software");
            _mimeTypeDictionary.Add(".aps"      , "application/mime"                                     );
            _mimeTypeDictionary.Add(".arc"      , "application/octet-stream"                             );
            _mimeTypeDictionary.Add(".arj"      , "application/arj"                                      );
            _mimeTypeDictionary.Add(".art"      , "image/x-jg"                                           );
            _mimeTypeDictionary.Add(".asf"      , "video/x-ms-asf"                                       );
            _mimeTypeDictionary.Add(".asm"      , "text/x-asm"                                           );
            _mimeTypeDictionary.Add(".asp"      , "text/asp"                                             );
            _mimeTypeDictionary.Add(".asx"      , "application/x-mplayer2"                               );
            _mimeTypeDictionary.Add(".au"       , "audio/basic"                                          );
            _mimeTypeDictionary.Add(".avi"      , "video/avi"                                            );
            _mimeTypeDictionary.Add(".avs"      , "video/avs-video"                                      );
            _mimeTypeDictionary.Add(".bcpio"    , "application/x-bcpio"                                  );
            _mimeTypeDictionary.Add(".bin"      , "application/octet-stream"                             );
            _mimeTypeDictionary.Add(".bm"       , "image/bmp"                                            );
            _mimeTypeDictionary.Add(".bmp"      , "image/bmp"                                            );
            _mimeTypeDictionary.Add(".boo"      , "application/book"                                     );
            _mimeTypeDictionary.Add(".book"     , "application/book"                                     );
            _mimeTypeDictionary.Add(".boz"      , "application/x-bzip2"                                  );
            _mimeTypeDictionary.Add(".bsh"      , "application/x-bsh"                                    );
            _mimeTypeDictionary.Add(".bz"       , "application/x-bzip"                                   );
            _mimeTypeDictionary.Add(".bz2"      , "application/x-bzip2"                                  );
            _mimeTypeDictionary.Add(".c"        , "text/plain"                                           );
            _mimeTypeDictionary.Add(".c++"      , "text/plain"                                           );
            _mimeTypeDictionary.Add(".cat"      , "application/vnd.ms-pki.seccat"                        );
            _mimeTypeDictionary.Add(".cc"       , "text/plain"                                           );
            _mimeTypeDictionary.Add(".ccad"     , "application/clariscad"                                );
            _mimeTypeDictionary.Add(".cco"      , "application/x-cocoa"                                  );
            _mimeTypeDictionary.Add(".cdf"      , "application/cdf"                                      );
            _mimeTypeDictionary.Add(".cer"      , "application/pkix-cert"                                );
            _mimeTypeDictionary.Add(".cha"      , "application/x-chat"                                   );
            _mimeTypeDictionary.Add(".chat"     , "application/x-chat"                                   );
            _mimeTypeDictionary.Add(".class"    , "application/java"                                     );
            _mimeTypeDictionary.Add(".com"      , "application/octet-stream"                             );
            _mimeTypeDictionary.Add(".conf"     , "text/plain"                                           );
            _mimeTypeDictionary.Add(".cpio"     , "application/x-cpio"                                   );
            _mimeTypeDictionary.Add(".cpp"      , "text/x-c"                                             );
            _mimeTypeDictionary.Add(".cpt"      , "application/x-cpt"                                    );
            _mimeTypeDictionary.Add(".crl"      , "application/pkcs-crl"                                 );
            _mimeTypeDictionary.Add(".css"      , "text/css"                                             );
            _mimeTypeDictionary.Add(".def"      , "text/plain"                                           );
            _mimeTypeDictionary.Add(".der"      , "application/x-x509-ca-cert"                           );
            _mimeTypeDictionary.Add(".dif"      , "video/x-dv"                                           );
            _mimeTypeDictionary.Add(".dir"      , "application/x-director"                               );
            _mimeTypeDictionary.Add(".dl"       , "video/dl"                                             );
            _mimeTypeDictionary.Add(".doc"      , "application/msword"                                   );
            _mimeTypeDictionary.Add(".dot"      , "application/msword"                                   );
            _mimeTypeDictionary.Add(".dp"       , "application/commonground"                             );
            _mimeTypeDictionary.Add(".drw"      , "application/drafting"                                 );
            _mimeTypeDictionary.Add(".dump"     , "application/octet-stream"                             );
            _mimeTypeDictionary.Add(".dv"       , "video/x-dv"                                           );
            _mimeTypeDictionary.Add(".dvi"      , "application/x-dvi"                                    );
            _mimeTypeDictionary.Add(".dwf"      , "drawing/x-dwf (old)"                                  );
            _mimeTypeDictionary.Add(".dwg"      , "application/acad"                                     );
            _mimeTypeDictionary.Add(".dxf"      , "application/dxf"                                      );
            _mimeTypeDictionary.Add(".eps"      , "application/postscript"                               );
            _mimeTypeDictionary.Add(".es"       , "application/x-esrehber"                               );
            _mimeTypeDictionary.Add(".etx"      , "text/x-setext"                                        );
            _mimeTypeDictionary.Add(".evy"      , "application/envoy"                                    );
            _mimeTypeDictionary.Add(".exe"      , "application/octet-stream"                             );
            _mimeTypeDictionary.Add(".f"        , "text/plain"                                           );
            _mimeTypeDictionary.Add(".f90"      , "text/x-fortran"                                       );
            _mimeTypeDictionary.Add(".fdf"      , "application/vnd.fdf"                                  );
            _mimeTypeDictionary.Add(".fif"      , "image/fif"                                            );
            _mimeTypeDictionary.Add(".fli"      , "video/fli"                                            );
            _mimeTypeDictionary.Add(".flv"      , "video/x-flv"                                          );
            _mimeTypeDictionary.Add(".for"      , "text/x-fortran"                                       );
            _mimeTypeDictionary.Add(".fpx"      , "image/vnd.fpx"                                        );
            _mimeTypeDictionary.Add(".g"        , "text/plain"                                           );
            _mimeTypeDictionary.Add(".g3"       , "image/g3fax"                                          );
            _mimeTypeDictionary.Add(".gif"      , "image/gif"                                            );
            _mimeTypeDictionary.Add(".gl"       , "video/gl"                                             );
            _mimeTypeDictionary.Add(".gsd"      , "audio/x-gsm"                                          );
            _mimeTypeDictionary.Add(".gtar"     , "application/x-gtar"                                   );
            _mimeTypeDictionary.Add(".gz"       , "application/x-compressed"                             );
            _mimeTypeDictionary.Add(".h"        , "text/plain"                                           );
            _mimeTypeDictionary.Add(".help"     , "application/x-helpfile"                               );
            _mimeTypeDictionary.Add(".hgl"      , "application/vnd.hp-hpgl"                              );
            _mimeTypeDictionary.Add(".hh"       , "text/plain"                                           );
            _mimeTypeDictionary.Add(".hlp"      , "application/x-winhelp"                                );
            _mimeTypeDictionary.Add(".htc"      , "text/x-component"                                     );
            _mimeTypeDictionary.Add(".htm"      , "text/html"                                            );
            _mimeTypeDictionary.Add(".html"     , "text/html"                                            );
            _mimeTypeDictionary.Add(".htmls"    , "text/html"                                            );
            _mimeTypeDictionary.Add(".htt"      , "text/webviewhtml"                                     );
            _mimeTypeDictionary.Add(".htx"      , "text/html"                                            );
            _mimeTypeDictionary.Add(".ice"      , "x-conference/x-cooltalk"                              );
            _mimeTypeDictionary.Add(".ico"      , "image/x-icon"                                         );
            _mimeTypeDictionary.Add(".idc"      , "text/plain"                                           );
            _mimeTypeDictionary.Add(".ief"      , "image/ief"                                            );
            _mimeTypeDictionary.Add(".iefs"     , "image/ief"                                            );
            _mimeTypeDictionary.Add(".iges"     , "application/iges"                                     );
            _mimeTypeDictionary.Add(".igs"      , "application/iges"                                     );
            _mimeTypeDictionary.Add(".ima"      , "application/x-ima"                                    );
            _mimeTypeDictionary.Add(".imap"     , "application/x-httpd-imap"                             );
            _mimeTypeDictionary.Add(".inf"      , "application/inf"                                      );
            _mimeTypeDictionary.Add(".ins"      , "application/x-internett-signup"                       );
            _mimeTypeDictionary.Add(".ip"       , "application/x-ip2"                                    );
            _mimeTypeDictionary.Add(".isu"      , "video/x-isvideo"                                      );
            _mimeTypeDictionary.Add(".it"       , "audio/it"                                             );
            _mimeTypeDictionary.Add(".iv"       , "application/x-inventor"                               );
            _mimeTypeDictionary.Add(".ivr"      , "i-world/i-vrml"                                       );
            _mimeTypeDictionary.Add(".ivy"      , "application/x-livescreen"                             );
            _mimeTypeDictionary.Add(".jam"      , "audio/x-jam"                                          );
            _mimeTypeDictionary.Add(".jav"      , "text/plain"                                           );
            _mimeTypeDictionary.Add(".java"     , "text/plain"                                           );
            _mimeTypeDictionary.Add(".jcm"      , "application/x-java-commerce"                          );
            _mimeTypeDictionary.Add(".jfif"     , "image/jpeg"                                           );
            _mimeTypeDictionary.Add(".jfif-tbnl", "image/jpeg"                                           );
            _mimeTypeDictionary.Add(".jpe"      , "image/jpeg"                                           );
            _mimeTypeDictionary.Add(".jpeg"     , "image/jpeg"                                           );
            _mimeTypeDictionary.Add(".jpg"      , "image/jpeg"                                           );
            _mimeTypeDictionary.Add(".jps"      , "image/x-jps"                                          );
            _mimeTypeDictionary.Add(".js"       , "application/x-javascript"                             );
            _mimeTypeDictionary.Add(".jut"      , "image/jutvision"                                      );
            _mimeTypeDictionary.Add(".kar"      , "audio/midi"                                           );
            _mimeTypeDictionary.Add(".ksh"      , "application/x-ksh"                                    );
            _mimeTypeDictionary.Add(".la"       , "audio/nspaudio"                                       );
            _mimeTypeDictionary.Add(".lam"      , "audio/x-liveaudio"                                    );
            _mimeTypeDictionary.Add(".latex"    , "application/x-latex"                                  );
            _mimeTypeDictionary.Add(".lha"      , "application/lha"                                      );
            _mimeTypeDictionary.Add(".lhx"      , "application/octet-stream"                             );
            _mimeTypeDictionary.Add(".list"     , "text/plain"                                           );
            _mimeTypeDictionary.Add(".lma"      , "audio/nspaudio"                                       );
            _mimeTypeDictionary.Add(".log"      , "text/plain"                                           );
            _mimeTypeDictionary.Add(".lsp"      , "application/x-lisp"                                   );
            _mimeTypeDictionary.Add(".lst"      , "text/plain"                                           );
            _mimeTypeDictionary.Add(".lsx"      , "text/x-la-asf"                                        );
            _mimeTypeDictionary.Add(".ltx"      , "application/x-latex"                                  );
            _mimeTypeDictionary.Add(".lzh"      , "application/octet-stream"                             );
            _mimeTypeDictionary.Add(".lzx"      , "application/lzx"                                      );
            _mimeTypeDictionary.Add(".m"        , "text/plain"                                           );
            _mimeTypeDictionary.Add(".m1v"      , "video/mpeg"                                           );
            _mimeTypeDictionary.Add(".m2a"      , "audio/mpeg"                                           );
            _mimeTypeDictionary.Add(".m2v"      , "video/mpeg"                                           );
            _mimeTypeDictionary.Add(".m3u"      , "audio/x-mpequrl"                                      );
            _mimeTypeDictionary.Add(".man"      , "application/x-troff-man"                              );
            _mimeTypeDictionary.Add(".map"      , "application/x-navimap"                                );
            _mimeTypeDictionary.Add(".mar"      , "text/plain"                                           );
            _mimeTypeDictionary.Add(".mbd"      , "application/mbedlet"                                  );
            _mimeTypeDictionary.Add(".mc$"      , "application/x-magic-cap-package-1.0"                  );
            _mimeTypeDictionary.Add(".mcd"      , "application/mcad"                                     );
            _mimeTypeDictionary.Add(".mcf"      , "image/vasa"                                           );
            _mimeTypeDictionary.Add(".mcp"      , "application/netmc"                                    );
            _mimeTypeDictionary.Add(".me"       , "application/x-troff-me"                               );
            _mimeTypeDictionary.Add(".mht"      , "message/rfc822"                                       );
            _mimeTypeDictionary.Add(".mhtml"    , "message/rfc822"                                       );
            _mimeTypeDictionary.Add(".mid"      , "audio/midi"                                           );
            _mimeTypeDictionary.Add(".midi"     , "audio/midi"                                           );
            _mimeTypeDictionary.Add(".mif"      , "application/x-frame"                                  );
            _mimeTypeDictionary.Add(".mime"     , "message/rfc822"                                       );
            _mimeTypeDictionary.Add(".mjf"      , "audio/x-vnd.audioexplosion.mjuicemediafile"           );
            _mimeTypeDictionary.Add(".mjpg"     , "video/x-motion-jpeg"                                  );
            _mimeTypeDictionary.Add(".mm"       , "application/base64"                                   );
            _mimeTypeDictionary.Add(".mme"      , "application/base64"                                   );
            _mimeTypeDictionary.Add(".mod"      , "audio/mod"                                            );
            _mimeTypeDictionary.Add(".moov"     , "video/quicktime"                                      );
            _mimeTypeDictionary.Add(".mov"      , "video/quicktime"                                      );
            _mimeTypeDictionary.Add(".movie"    , "video/x-sgi-movie"                                    );
            _mimeTypeDictionary.Add(".mp2"      , "audio/mpeg"                                           );
            _mimeTypeDictionary.Add(".mp3"      , "audio/mpeg3"                                          );
            _mimeTypeDictionary.Add(".mpa"      , "audio/mpeg"                                           );
            _mimeTypeDictionary.Add(".mpc"      , "application/x-project"                                );
            _mimeTypeDictionary.Add(".mpe"      , "video/mpeg"                                           );
            _mimeTypeDictionary.Add(".mpeg"     , "video/mpeg"                                           );
            _mimeTypeDictionary.Add(".mpg"      , "video/mpeg"                                           );
            _mimeTypeDictionary.Add(".mpga"     , "audio/mpeg"                                           );
            _mimeTypeDictionary.Add(".mpp"      , "application/vnd.ms-project"                           );
            _mimeTypeDictionary.Add(".mpt"      , "application/x-project"                                );
            _mimeTypeDictionary.Add(".mpv"      , "application/x-project"                                );
            _mimeTypeDictionary.Add(".mpx"      , "application/x-project"                                );
            _mimeTypeDictionary.Add(".mrc"      , "application/marc"                                     );
            _mimeTypeDictionary.Add(".ms"       , "application/x-troff-ms"                               );
            _mimeTypeDictionary.Add(".mv"       , "video/x-sgi-movie"                                    );
            _mimeTypeDictionary.Add(".my"       , "audio/make"                                           );
            _mimeTypeDictionary.Add(".mzz"      , "application/x-vnd.audioexplosion.mzz"                 );
            _mimeTypeDictionary.Add(".nap"      , "image/naplps"                                         );
            _mimeTypeDictionary.Add(".naplps"   , "image/naplps"                                         );
            _mimeTypeDictionary.Add(".nc"       , "application/x-netcdf"                                 );
            _mimeTypeDictionary.Add(".ncm"      , "application/vnd.nokia.configuration-message"          );
            _mimeTypeDictionary.Add(".nif"      , "image/x-niff"                                         );
            _mimeTypeDictionary.Add(".niff"     , "image/x-niff"                                         );
            _mimeTypeDictionary.Add(".nix"      , "application/x-mix-transfer"                           );
            _mimeTypeDictionary.Add(".nsc"      , "application/x-conference"                             );
            _mimeTypeDictionary.Add(".nvd"      , "application/x-navidoc"                                );
            _mimeTypeDictionary.Add(".o"        , "application/octet-stream"                             );
            _mimeTypeDictionary.Add(".oda"      , "application/oda"                                      );
            _mimeTypeDictionary.Add(".omc"      , "application/x-omc"                                    );
            _mimeTypeDictionary.Add(".omcd"     , "application/x-omcdatamaker"                           );
            _mimeTypeDictionary.Add(".omcr"     , "application/x-omcregerator"                           );
            _mimeTypeDictionary.Add(".p"        , "text/x-pascal"                                        );
            _mimeTypeDictionary.Add(".p10"      , "application/pkcs10"                                   );
            _mimeTypeDictionary.Add(".p12"      , "application/pkcs-12"                                  );
            _mimeTypeDictionary.Add(".p7a"      , "application/x-pkcs7-signature"                        );
            _mimeTypeDictionary.Add(".p7c"      , "application/pkcs7-mime"                               );
            _mimeTypeDictionary.Add(".pas"      , "text/pascal"                                          );
            _mimeTypeDictionary.Add(".pbm"      , "image/x-portable-bitmap"                              );
            _mimeTypeDictionary.Add(".pcl"      , "application/vnd.hp-pcl"                               );
            _mimeTypeDictionary.Add(".pct"      , "image/x-pict"                                         );
            _mimeTypeDictionary.Add(".pcx"      , "image/x-pcx"                                          );
            _mimeTypeDictionary.Add(".pdf"      , "application/pdf"                                      );
            _mimeTypeDictionary.Add(".pfunk"    , "audio/make"                                           );
            _mimeTypeDictionary.Add(".pgm"      , "image/x-portable-graymap"                             );
            _mimeTypeDictionary.Add(".pic"      , "image/pict"                                           );
            _mimeTypeDictionary.Add(".pict"     , "image/pict"                                           );
            _mimeTypeDictionary.Add(".pkg"      , "application/x-newton-compatible-pkg"                  );
            _mimeTypeDictionary.Add(".pko"      , "application/vnd.ms-pki.pko"                           );
            _mimeTypeDictionary.Add(".pl"       , "text/plain"                                           );
            _mimeTypeDictionary.Add(".plx"      , "application/x-pixclscript"                            );
            _mimeTypeDictionary.Add(".pm"       , "image/x-xpixmap"                                      );
            _mimeTypeDictionary.Add(".png"      , "image/png"                                            );
            _mimeTypeDictionary.Add(".pnm"      , "application/x-portable-anymap"                        );
            _mimeTypeDictionary.Add(".pot"      , "application/mspowerpoint"                             );
            _mimeTypeDictionary.Add(".pov"      , "model/x-pov"                                          );
            _mimeTypeDictionary.Add(".ppa"      , "application/vnd.ms-powerpoint"                        );
            _mimeTypeDictionary.Add(".ppm"      , "image/x-portable-pixmap"                              );
            _mimeTypeDictionary.Add(".pps"      , "application/mspowerpoint"                             );
            _mimeTypeDictionary.Add(".ppt"      , "application/mspowerpoint"                             );
            _mimeTypeDictionary.Add(".ppz"      , "application/mspowerpoint"                             );
            _mimeTypeDictionary.Add(".pre"      , "application/x-freelance"                              );
            _mimeTypeDictionary.Add(".prt"      , "application/pro_eng"                                  );
            _mimeTypeDictionary.Add(".ps"       , "application/postscript"                               );
            _mimeTypeDictionary.Add(".psd"      , "application/octet-stream"                             );
            _mimeTypeDictionary.Add(".pvu"      , "paleovu/x-pv"                                         );
            _mimeTypeDictionary.Add(".pwz"      , "application/vnd.ms-powerpoint"                        );
            _mimeTypeDictionary.Add(".py"       , "text/x-script.phyton"                                 );
            _mimeTypeDictionary.Add(".pyc"      , "applicaiton/x-bytecode.python"                        );
            _mimeTypeDictionary.Add(".qcp"      , "audio/vnd.qcelp"                                      );
            _mimeTypeDictionary.Add(".qd3"      , "x-world/x-3dmf"                                       );
            _mimeTypeDictionary.Add(".qd3d"     , "x-world/x-3dmf"                                       );
            _mimeTypeDictionary.Add(".qif"      , "image/x-quicktime"                                    );
            _mimeTypeDictionary.Add(".qt"       , "video/quicktime"                                      );
            _mimeTypeDictionary.Add(".qtc"      , "video/x-qtc"                                          );
            _mimeTypeDictionary.Add(".qti"      , "image/x-quicktime"                                    );
            _mimeTypeDictionary.Add(".qtif"     , "image/x-quicktime"                                    );
            _mimeTypeDictionary.Add(".ra"       , "audio/x-pn-realaudio"                                 );
            _mimeTypeDictionary.Add(".ram"      , "audio/x-pn-realaudio"                                 );
            _mimeTypeDictionary.Add(".ras"      , "application/x-cmu-raster"                             );
            _mimeTypeDictionary.Add(".rast"     , "image/cmu-raster"                                     );
            _mimeTypeDictionary.Add(".rexx"     , "text/x-script.rexx"                                   );
            _mimeTypeDictionary.Add(".rf"       , "image/vnd.rn-realflash"                               );
            _mimeTypeDictionary.Add(".rgb"      , "image/x-rgb"                                          );
            _mimeTypeDictionary.Add(".rm"       , "application/vnd.rn-realmedia"                         );
            _mimeTypeDictionary.Add(".rmi"      , "audio/mid"                                            );
            _mimeTypeDictionary.Add(".rmm"      , "audio/x-pn-realaudio"                                 );
            _mimeTypeDictionary.Add(".rmp"      , "audio/x-pn-realaudio"                                 );
            _mimeTypeDictionary.Add(".rng"      , "application/ringing-tones"                            );
            _mimeTypeDictionary.Add(".rnx"      , "application/vnd.rn-realplayer"                        );
            _mimeTypeDictionary.Add(".roff"     , "application/x-troff"                                  );
            _mimeTypeDictionary.Add(".rp"       , "image/vnd.rn-realpix"                                 );
            _mimeTypeDictionary.Add(".rpm"      , "audio/x-pn-realaudio-plugin"                          );
            _mimeTypeDictionary.Add(".rt"       , "text/richtext"                                        );
            _mimeTypeDictionary.Add(".rtf"      , "text/richtext"                                        );
            _mimeTypeDictionary.Add(".rtx"      , "application/rtf"                                      );
            _mimeTypeDictionary.Add(".rv"       , "video/vnd.rn-realvideo"                               );
            _mimeTypeDictionary.Add(".s"        , "text/x-asm"                                           );
            _mimeTypeDictionary.Add(".s3m"      , "audio/s3m"                                            );
            _mimeTypeDictionary.Add(".saveme"   , "application/octet-stream"                             );
            _mimeTypeDictionary.Add(".sbk"      , "application/x-tbook"                                  );
            _mimeTypeDictionary.Add(".scm"      , "application/x-lotusscreencam"                         );
            _mimeTypeDictionary.Add(".sdml"     , "text/plain"                                           );
            _mimeTypeDictionary.Add(".sdp"      , "application/sdp"                                      );
            _mimeTypeDictionary.Add(".sdr"      , "application/sounder"                                  );
            _mimeTypeDictionary.Add(".sea"      , "application/sea"                                      );
            _mimeTypeDictionary.Add(".set"      , "application/set"                                      );
            _mimeTypeDictionary.Add(".sgm"      , "text/sgml"                                            );
            _mimeTypeDictionary.Add(".sgml"     , "text/sgml"                                            );
            _mimeTypeDictionary.Add(".sh"       , "application/x-bsh"                                    );
            _mimeTypeDictionary.Add(".shtml"    , "text/html"                                            );
            _mimeTypeDictionary.Add(".sid"      , "audio/x-psid"                                         );
            _mimeTypeDictionary.Add(".sit"      , "application/x-sit"                                    );
            _mimeTypeDictionary.Add(".skd"      , "application/x-koan"                                   );
            _mimeTypeDictionary.Add(".skm"      , "application/x-koan"                                   );
            _mimeTypeDictionary.Add(".skp"      , "application/x-koan"                                   );
            _mimeTypeDictionary.Add(".skt"      , "application/x-koan"                                   );
            _mimeTypeDictionary.Add(".sl"       , "application/x-seelogo"                                );
            _mimeTypeDictionary.Add(".smi"      , "application/smil"                                     );
            _mimeTypeDictionary.Add(".smil"     , "application/smil"                                     );
            _mimeTypeDictionary.Add(".snd"      , "audio/basic"                                          );
            _mimeTypeDictionary.Add(".sol"      , "application/solids"                                   );
            _mimeTypeDictionary.Add(".spc"      , "application/x-pkcs7-certificates"                     );
            _mimeTypeDictionary.Add(".spl"      , "application/futuresplash"                             );
            _mimeTypeDictionary.Add(".spr"      , "application/x-sprite"                                 );
            _mimeTypeDictionary.Add(".sprite"   , "application/x-sprite"                                 );
            _mimeTypeDictionary.Add(".src"      , "application/x-wais-source"                            );
            _mimeTypeDictionary.Add(".ssi"      , "text/x-server-parsed-html"                            );
            _mimeTypeDictionary.Add(".ssm"      , "application/streamingmedia"                           );
            _mimeTypeDictionary.Add(".sst"      , "application/vnd.ms-pki.certstore"                     );
            _mimeTypeDictionary.Add(".step"     , "application/step"                                     );
            _mimeTypeDictionary.Add(".stl"      , "application/sla"                                      );
            _mimeTypeDictionary.Add(".stp"      , "application/step"                                     );
            _mimeTypeDictionary.Add(".sv4cpio"  , "application/x-sv4cpio"                                );
            _mimeTypeDictionary.Add(".sv4crc"   , "application/x-sv4crc"                                 );
            _mimeTypeDictionary.Add(".svf"      , "image/vnd.dwg"                                        );
            _mimeTypeDictionary.Add(".svr"      , "application/x-world"                                  );
            _mimeTypeDictionary.Add(".swf"      , "application/x-shockwave-flash"                        );
            _mimeTypeDictionary.Add(".t"        , "application/x-troff"                                  );
            _mimeTypeDictionary.Add(".talk"     , "text/x-speech"                                        );
            _mimeTypeDictionary.Add(".tar"      , "application/x-tar"                                    );
            _mimeTypeDictionary.Add(".tbk"      , "application/toolbook"                                 );
            _mimeTypeDictionary.Add(".tcl"      , "application/x-tcl"                                    );
            _mimeTypeDictionary.Add(".tcsh"     , "text/x-script.tcsh"                                   );
            _mimeTypeDictionary.Add(".tex"      , "application/x-tex"                                    );
            _mimeTypeDictionary.Add(".texi"     , "application/x-texinfo"                                );
            _mimeTypeDictionary.Add(".texinfo"  , "application/x-texinfo"                                );
            _mimeTypeDictionary.Add(".text"     , "text/plain"                                           );
            _mimeTypeDictionary.Add(".tgz"      , "application/x-compressed"                             );
            _mimeTypeDictionary.Add(".tif"      , "image/tiff"                                           );
            _mimeTypeDictionary.Add(".tr"       , "application/x-troff"                                  );
            _mimeTypeDictionary.Add(".tsi"      , "audio/tsp-audio"                                      );
            _mimeTypeDictionary.Add(".tsp"      , "audio/tsplayer"                                       );
            _mimeTypeDictionary.Add(".tsv"      , "text/tab-separated-values"                            );
            _mimeTypeDictionary.Add(".turbot"   , "image/florian"                                        );
            _mimeTypeDictionary.Add(".txt"      , "text/plain"                                           );
            _mimeTypeDictionary.Add(".uil"      , "text/x-uil"                                           );
            _mimeTypeDictionary.Add(".uni"      , "text/uri-list"                                        );
            _mimeTypeDictionary.Add(".unis"     , "text/uri-list"                                        );
            _mimeTypeDictionary.Add(".unv"      , "application/i-deas"                                   );
            _mimeTypeDictionary.Add(".uri"      , "text/uri-list"                                        );
            _mimeTypeDictionary.Add(".uris"     , "text/uri-list"                                        );
            _mimeTypeDictionary.Add(".ustar"    , "application/x-ustar"                                  );
            _mimeTypeDictionary.Add(".uu"       , "application/octet-stream"                             );
            _mimeTypeDictionary.Add(".vcd"      , "application/x-cdlink"                                 );
            _mimeTypeDictionary.Add(".vcs"      , "text/x-vcalendar"                                     );
            _mimeTypeDictionary.Add(".vda"      , "application/vda"                                      );
            _mimeTypeDictionary.Add(".vdo"      , "video/vdo"                                            );
            _mimeTypeDictionary.Add(".vew"      , "application/groupwise"                                );
            _mimeTypeDictionary.Add(".viv"      , "video/vivo"                                           );
            _mimeTypeDictionary.Add(".vivo"     , "video/vivo"                                           );
            _mimeTypeDictionary.Add(".vmd"      , "application/vocaltec-media-desc"                      );
            _mimeTypeDictionary.Add(".vmf"      , "application/vocaltec-media-file"                      );
            _mimeTypeDictionary.Add(".voc"      , "audio/voc"                                            );
            _mimeTypeDictionary.Add(".vos"      , "video/vosaic"                                         );
            _mimeTypeDictionary.Add(".vox"      , "audio/voxware"                                        );
            _mimeTypeDictionary.Add(".vqe"      , "audio/x-twinvq-plugin"                                );
            _mimeTypeDictionary.Add(".vqf"      , "audio/x-twinvq"                                       );
            _mimeTypeDictionary.Add(".vql"      , "audio/x-twinvq-plugin"                                );
            _mimeTypeDictionary.Add(".vrml"     , "application/x-vrml"                                   );
            _mimeTypeDictionary.Add(".vrt"      , "x-world/x-vrt"                                        );
            _mimeTypeDictionary.Add(".vsd"      , "application/x-visio"                                  );
            _mimeTypeDictionary.Add(".vst"      , "application/x-visio"                                  );
            _mimeTypeDictionary.Add(".vsw"      , "application/x-visio"                                  );
            _mimeTypeDictionary.Add(".w60"      , "application/wordperfect6.0"                           );
            _mimeTypeDictionary.Add(".w61"      , "application/wordperfect6.1"                           );
            _mimeTypeDictionary.Add(".w6w"      , "application/msword"                                   );
            _mimeTypeDictionary.Add(".wav"      , "audio/wav"                                            );
            _mimeTypeDictionary.Add(".wb1"      , "application/x-qpro"                                   );
            _mimeTypeDictionary.Add(".wbmp"     , "image/vnd.wap.wbmp"                                   );
            _mimeTypeDictionary.Add(".web"      , "application/vnd.xara"                                 );
            _mimeTypeDictionary.Add(".wiz"      , "application/msword"                                   );
            _mimeTypeDictionary.Add(".wk1"      , "application/x-123"                                    );
            _mimeTypeDictionary.Add(".wmf"      , "windows/metafile"                                     );
            _mimeTypeDictionary.Add(".wml"      , "text/vnd.wap.wml"                                     );
            _mimeTypeDictionary.Add(".wmlc"     , "application/vnd.wap.wmlc"                             );
            _mimeTypeDictionary.Add(".wmls"     , "text/vnd.wap.wmlscript"                               );
            _mimeTypeDictionary.Add(".wmlsc"    , "application/vnd.wap.wmlscriptc"                       );
            _mimeTypeDictionary.Add(".word"     , "application/msword"                                   );
            _mimeTypeDictionary.Add(".wp"       , "application/wordperfect"                              );
            _mimeTypeDictionary.Add(".wp5"      , "application/wordperfect"                              );
            _mimeTypeDictionary.Add(".wp6"      , "application/wordperfect"                              );
            _mimeTypeDictionary.Add(".wpd"      , "application/wordperfect"                              );
            _mimeTypeDictionary.Add(".wq1"      , "application/x-lotus"                                  );
            _mimeTypeDictionary.Add(".wri"      , "application/mswrite"                                  );
            _mimeTypeDictionary.Add(".wrl"      , "application/x-world"                                  );
            _mimeTypeDictionary.Add(".wrz"      , "model/vrml"                                           );
            _mimeTypeDictionary.Add(".wsc"      , "text/scriplet"                                        );
            _mimeTypeDictionary.Add(".wsrc"     , "application/x-wais-source"                            );
            _mimeTypeDictionary.Add(".wtk"      , "application/x-wintalk"                                );
            _mimeTypeDictionary.Add(".x-png"    , "image/png"                                            );
            _mimeTypeDictionary.Add(".xbm"      , "image/x-xbitmap"                                      );
            _mimeTypeDictionary.Add(".xdr"      , "video/x-amt-demorun"                                  );
            _mimeTypeDictionary.Add(".xgz"      , "xgl/drawing"                                          );
            _mimeTypeDictionary.Add(".xif"      , "image/vnd.xiff"                                       );
            _mimeTypeDictionary.Add(".xl"       , "application/excel"                                    );
            _mimeTypeDictionary.Add(".xla"      , "application/excel"                                    );
            _mimeTypeDictionary.Add(".xlb"      , "application/excel"                                    );
            _mimeTypeDictionary.Add(".xlc"      , "application/excel"                                    );
            _mimeTypeDictionary.Add(".xld"      , "application/excel"                                    );
            _mimeTypeDictionary.Add(".xlk"      , "application/excel"                                    );
            _mimeTypeDictionary.Add(".xll"      , "application/excel"                                    );
            _mimeTypeDictionary.Add(".xlm"      , "application/excel"                                    );
            _mimeTypeDictionary.Add(".xls"      , "application/excel"                                    );
            _mimeTypeDictionary.Add(".xlsx"     , "application/excel"                                    );
            _mimeTypeDictionary.Add(".xlt"      , "application/excel"                                    );
            _mimeTypeDictionary.Add(".xlv"      , "application/excel"                                    );
            _mimeTypeDictionary.Add(".xlw"      , "application/excel"                                    );
            _mimeTypeDictionary.Add(".xm"       , "audio/xm"                                             );
            _mimeTypeDictionary.Add(".xml"      , "text/xml"                                             );
            _mimeTypeDictionary.Add(".xmz"      , "xgl/movie"                                            );
            _mimeTypeDictionary.Add(".xpix"     , "application/x-vnd.ls-xpix"                            );
            _mimeTypeDictionary.Add(".xpm"      , "image/x-xpixmap"                                      );
            _mimeTypeDictionary.Add(".xsr"      , "video/x-amt-showrun"                                  );
            _mimeTypeDictionary.Add(".xwd"      , "image/x-xwd"                                          );
            _mimeTypeDictionary.Add(".xyz"      , "chemical/x-pdb"                                       );
            _mimeTypeDictionary.Add(".z"        , "application/x-compress"                               );
            _mimeTypeDictionary.Add(".zip"      , "application/x-compressed"                             );
            _mimeTypeDictionary.Add(".zoo"      , "application/octet-stream"                             );
            _mimeTypeDictionary.Add(".zsh"      , "text/x-script.zsh"                                    );
        }

        #endregion
    }
}