﻿using Microsoft.Office.Core;
using Microsoft.Office.Interop.Outlook;
using System;
using System.Collections.Generic;
using System.IO;
using System.Reflection;
using System.Runtime.InteropServices;
using System.Windows.Forms;

using MimeKit;

namespace TestProject
{
    /// <summary>
    /// 리본 컨텍스트 메뉴
    /// </summary>
    [ComVisible(true)]
    public class RibbonContextMenu : IRibbonExtensibility
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Field
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region Field

        /// <summary>
        /// 리본 UI
        /// </summary>
        private IRibbonUI ribbonUI;

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Constructor
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 생성자 - RibbonContextMenu()

        /// <summary>
        /// 생성자
        /// </summary>
        public RibbonContextMenu()
        {
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Public
        //////////////////////////////////////////////////////////////////////////////// Event

        #region 커스텀 UI 로드시 처리하기 - customUI_onLoad(ribbonUI)

        /// <summary>
        /// 커스텀 UI 로드시 처리하기
        /// </summary>
        /// <param name="ribbonUI">리본 UI</param>
        public void customUI_onLoad(IRibbonUI ribbonUI)
        {
            this.ribbonUI = ribbonUI;
        }

        #endregion
        #region 컨텍스트 메뉴 작업시 처리하기 - contextMenu_onAction(ribbonControl)

        /// <summary>
        /// 컨텍스트 메뉴 작업시 처리하기
        /// </summary>
        /// <param name="ribbonControl">리본 컨트롤</param>
        public void contextMenu_onAction(IRibbonControl ribbonControl)
        {
            switch(ribbonControl.Id)
            {
                case "saveEMLFileButton" :

                    try
                    {
                        dynamic itemCollection = ribbonControl.Context;

                        foreach(dynamic item in itemCollection)
                        {
                            if(item is MailItem mailItem)
                            {
                                SaveEMLFile(mailItem, "d:\\test.eml");
                            }
                        }
                    }
                    catch(System.Exception exception)
                    {
                        MessageBox.Show($"예외가 발생하였습니다.\r\n{exception.ToString()}");
                    }

                    break;
            }
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////// Function

        #region (IRibbonExtensibility) 커스텀 UI 구하기 - GetCustomUI(ribbonID)

        /// <summary>
        /// 커스텀 UI 구하기
        /// </summary>
        /// <param name="ribbonID">리본 ID</param>
        /// <returns>커스텀 UI</returns>
        public string GetCustomUI(string ribbonID)
        {
            return ribbonID.Equals("Microsoft.Outlook.Explorer") ? GetResourceText("TestProject.RibbonContextMenu.xml") : null;
        }

        #endregion

        ////////////////////////////////////////////////////////////////////////////////////////// Private
        //////////////////////////////////////////////////////////////////////////////// Function

        #region 리소스 텍스트 구하기 - GetResourceText(resourceName)

        /// <summary>
        /// 리소스 텍스트 구하기
        /// </summary>
        /// <param name="resourceName">리소스명</param>
        /// <returns>리소스 텍스트</returns>
        private static string GetResourceText(string resourceName)
        {
            Assembly assembly = Assembly.GetExecutingAssembly();

            string[] resourceNameArray = assembly.GetManifestResourceNames();

            int count = resourceNameArray.Length;

            for(int i = 0; i < count; ++i)
            {
                if(string.Compare(resourceName, resourceNameArray[i], StringComparison.OrdinalIgnoreCase) == 0)
                {
                    using(StreamReader reader = new StreamReader(assembly.GetManifestResourceStream(resourceNameArray[i])))
                    {
                        if(reader != null)
                        {
                            return reader.ReadToEnd();
                        }
                    }
                }
            }

            return null;
        }

        #endregion

        #region EML 파일 저장하기 - SaveEMLFile(mailItem, filePath)

        /// <summary>
        /// EML 파일 저장하기
        /// </summary>
        /// <param name="mailItem">메일 항목</param>
        /// <param name="filePath">파일 경로</param>
        private void SaveEMLFile(MailItem mailItem, string filePath)
        {
            System.Net.Mail.MailMessage mailMessage = new System.Net.Mail.MailMessage();
                        
            mailMessage.Subject    = mailItem.Subject;
            mailMessage.From       = new System.Net.Mail.MailAddress(mailItem.Sender.Address, mailItem.Sender.Name);
            mailMessage.IsBodyHtml = mailItem.BodyFormat == OlBodyFormat.olFormatHTML;
            mailMessage.Body       = mailItem.BodyFormat == OlBodyFormat.olFormatHTML ? mailItem.HTMLBody : mailItem.Body;

            foreach(Recipient recipient in mailItem.Recipients)
            {
                if(recipient.Type == (int)OlMailRecipientType.olTo)
                {
                    mailMessage.To.Add(new System.Net.Mail.MailAddress(recipient.Address, recipient.Name));
                }
                else if(recipient.Type == (int)OlMailRecipientType.olCC)
                {
                    mailMessage.CC.Add(new System.Net.Mail.MailAddress(recipient.Address, recipient.Name));
                }
                else if(recipient.Type == (int)OlMailRecipientType.olBCC)
                {
                    mailMessage.Bcc.Add(new System.Net.Mail.MailAddress(recipient.Address, recipient.Name));
                }
            }

            List<string> temporaryDirectoryPathList = new List<string>();

            try
            {
                foreach(Attachment attachment in mailItem.Attachments)
                {
                    #region 임시 디렉토리 경로를 설정한다.

                    string temporaryDirectoryPath = Path.Combine(Path.GetTempPath(), "Temp", Guid.NewGuid().ToString());

                    #endregion
                    #region 임시 디렉토리 경로를 생성한다.

                    if(!Directory.Exists(temporaryDirectoryPath))
                    {
                        Directory.CreateDirectory(temporaryDirectoryPath);
                    }

                    #endregion

                    temporaryDirectoryPathList.Add(temporaryDirectoryPath);

                    #region 첨부 파일을 저장한다.

                    string attachmentFilePath = Path.Combine(temporaryDirectoryPath, attachment.FileName);

                    attachment.SaveAsFile(attachmentFilePath);

                    #endregion
                    #region MIME 타입을 설정한다.

                    string fileExtension = Path.GetExtension(attachment.FileName);

                    string mimeType = MIMETypeHelper.GetMIMEType(fileExtension);

                    #endregion

                    mailMessage.Attachments.Add(new System.Net.Mail.Attachment(attachmentFilePath, mimeType));
                }

                MimeMessage mimeMessage = (MimeMessage)mailMessage;

                mimeMessage.Date = mailItem.CreationTime;

                mimeMessage.WriteTo(filePath);

                mailMessage.Dispose();
            }
            finally
            {
                foreach(string path in temporaryDirectoryPathList)
                {
                    if(Directory.Exists(path))
                    {
                        Directory.Delete(path, true);
                    }
                }
            }
        }

        #endregion
    }
}